@@ -106,7 +106,7 @@ def is_ip_address(string_to_check):
     return False
 
 
-def resolve_dns(domain, timeout=5, lifetime=15, dns_server=None, first_result_only=True):
+def resolve_dns(domain, timeout=5, lifetime=15, dns_server=None, first_result_only=True, tcp=True):
     """Resolves the domain to an IP address. If no DNS server is provided, it will use the system's default DNS server.
     Timeout and lifetime are set to 5 and 15 seconds respectively by default.
 
@@ -116,6 +116,7 @@ def resolve_dns(domain, timeout=5, lifetime=15, dns_server=None, first_result_on
         lifetime (int, optional): The lifetime for the DNS resolver. Defaults to 10.
         dns_server (str, optional): The DNS server to use. Defaults to None.
         first_result_only (bool, optional): Whether to return only the first result. Defaults to True.
+        tcp (bool, optional): Whether to use TCP for the query. Defaults to True.
 
     Returns:
         str or list: The resolved IP address(es).
@@ -138,7 +139,7 @@ def resolve_dns(domain, timeout=5, lifetime=15, dns_server=None, first_result_on
         logging.debug(f"DNS server set to [{dns_server}].")
 
     try:
-        answer = resolver.resolve(domain)
+        answer = resolver.resolve(domain, tcp=tcp)
         logging.debug(f"Resolved {domain} to {answer}")
 
         # return the first result only if specified
